// --------------------------------------------------------------------------------------------------------------------
// <copyright file="decryptor.hh" company="Microsoft">
//  Copyright (c) Microsoft Corporation.  All rights reserved. 
// </copyright>
// <summary>
//   Wrapper class for decrypting strings
// </summary>
// --------------------------------------------------------------------------------------------------------------------
#ifndef _DECRYPTOR_H_
#define _DECRYPTOR_H_
#include <string>
#include "cryptutil.hh"

namespace cryptutil {
    class decryptor
	{
    private:
        // Path to a key
        std::string keyPath;
        // Password for decrypting the key (if one was provided)
        std::string keyPass;
	public:
		// Constructor
		decryptor(const std::string& _keyPath = "", const std::string& _keyPass = "") :
            keyPath(_keyPath), keyPass(_keyPass) {}

		// Copy Constructor
		decryptor(const decryptor& other)
        {
            keyPath = other.keyPath;
            keyPass = other.keyPass;
        }

        // Copy Operator
		decryptor& operator=(const decryptor& other)
        {
            if (this != &other)
            {
                keyPath = other.keyPath;
                keyPass = other.keyPass;
            }
            return *this;
        }

		// Move Constructor
		decryptor(decryptor&& other)
    	{
            keyPath = std::move(other.keyPath);
            keyPass = std::move(other.keyPass);
        }

        // Move Operator
		decryptor& operator= (decryptor&& other)
        {
            if (this != &other)
            {
                keyPath = std::move(other.keyPath);
                keyPass = std::move(other.keyPass);
            }
            return *this;
        }

        // Accessors
        std::string GetKeyPath() const
        {
            return keyPath;
        }

        std::string GetKeyPass() const
        {
            return keyPass;
        }

        // Mutators
        void SetKeyPath(const std::string& _keyPath)
        {
            keyPath = _keyPath;
        }
        
        void SetKeyPass(const std::string& _keyPass)
        {
            keyPass = _keyPass;
        }

        // Decryption Methods
        std::string DecodeAndDecryptFile(const std::string& filePath) const
        {
            return cryptutil::DecodeAndDecryptFile(keyPath, filePath, keyPass);
        }

        std::string DecodeAndDecryptString(const std::string& encodedCipherText) const
        {
            return cryptutil::DecodeAndDecryptString(keyPath, encodedCipherText, keyPass);
        }

        // Determine if this instance is capable of performing decryption functions
        bool IsValid() const
        {
            return !keyPath.empty();
        }
	};
}
#endif