#include "cryptutil.hh"

#include <iostream>

extern "C" {
#include <unistd.h>
}
using namespace std;

string binName="mondecrypt";

void ShowUsage()
{
    cerr << "Usage:" << endl
    << binName << " -e path -k path [-p pass] " << endl << endl
    << "    -e  Path to file containing encrypted contents" << endl
    << "    -k  Path to private key for decryption" << endl
    << "    -p  Password to decrypt private key" << endl;
	exit(1);
}

int main(int argc, char **argv)
{
    binName = string(argv[0]);
    string encFilePath, privKeyPath, keyPass;
    int c;
    while ((c = getopt (argc, argv, "e:k:p:h")) != -1)
    {
        switch(c)
        {
            case 'e':
                encFilePath = optarg;
                break;
            case 'k':
                privKeyPath = optarg;
                break;
            case 'p':
                keyPass = optarg;
                break;
            case 'h':
                ShowUsage();
                return 0;
            default:
                cerr << "Invalid option [" << c << "] specified" << endl;
                ShowUsage();
                return 1;
        }
    }
    if (encFilePath.empty() || privKeyPath.empty())
    {
        cerr << "Must specify privkey (-k) and encrypted file (-e)" << endl;
        ShowUsage();
        return 1;
    }
    try
    {
        auto result = cryptutil::DecodeAndDecryptFile(privKeyPath, encFilePath, keyPass);
        cout << result << endl;
    }
    catch (cryptutil::cryptutilException& ex)
    {
        cerr << "ERROR: " << ex.what() << endl;
        return 1;
    }
    return 0;
}


